/* Written by Dmitrij Schlesinger (2012),
 * www.inf.tu-dresden.de/~ds24/rtsegm/rtsegm.html
 *
 * The two classes below are a minimalistic wrapper for
 * the necessary OpenCV functionality. Tested with
 * OpenCV-2.3.1 under Ubuntu Linux 12.04 (gcc 4.6.3)
 * WindowsXP and Windows7 (Microsoft Visual Studio 2010).
*/

#ifndef __D_INOUT
#define __D_INOUT

#include <opencv2/core/core.hpp>
#include <opencv2/highgui/highgui.hpp>
#include <opencv2/imgproc/imgproc.hpp>
using namespace cv;

// This class implements a general "input" -- camera/video/image
class d_in {
public:
    d_in(int mode, int camera, char *filename, int height, int width, bool flip);
    ~d_in();

    // 0 -- camera, 1 -- video, 2 -- image
    int mode;
    bool manual_scale, flip;
    int height, width;
    // for camera/video
    VideoCapture *cap;
    // frames for reading from the camera/video/image
    Mat frame1, frame2, frame3;

    // the array, where the data is stored
    unsigned char *img;

    // launch
    bool in();

    // wait for a key delay miliseconds
    int key(int delay);
};

// This class implements a general "output" -- window/video/image
class d_out {
public:
    d_out(int mode, char *name, int height, int width, unsigned char *img);
    ~d_out();

    // 0 -- window, 1 -- video, 2 -- image
    int mode;
    // for window (mode=0) -- the window name/caption
    // otherwise -- the file name
    char *name;
    Mat *frame;
    int height, width;
    // for video (mode=1)
    VideoWriter *video;

    // launch
    void out();

    void draw_ellipse(int x0, int y0, int rx, int ry);
};

#endif
